@@ -686,6 +686,10 @@ class DAG(AbstractDAG):
             it's not possible to build a given task (e.g., missing upstream
             products), this will fail
         """
+
+        # we have to use a deep copy since using a soft one will corrupt
+        # task status in subsequent runs
+
         dag_copy = self._deepcopy_safe()
 
         # task names are usually str, although this isn't strictly enforced
@@ -870,7 +874,7 @@ class DAG(AbstractDAG):
                 outdated = task.product._is_outdated()
 
                 # add parameters for graphviz plotting
-                color = ('lightcoral' if outdated else 'lightgreen')
+                color = ('#F08080' if outdated else '#90EE90')
 
                 label = (_task_short_repr(task)
                          if include_products else task.name)
